==> cs_fyber_ad-0.0.5.tar.gz: example/lib/main.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:cs_fyber_ad/cs_fyber_ad.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();

    CsFyberAd().setOfferWallAvailable(offerWallAvailable);
    CsFyberAd().setOfferWallNotAvailable(offerWallNotAvailable);
    CsFyberAd().setOfferWallRequestError(offerWallRequestError);

    // CsFyberAd().setMediationNetworkStarted(mediationNetworkStarted);
    // CsFyberAd().setMediationNetworkFailed(mediationNetworkFailed);

    // CsFyberAd().setRewardedShowed(rewardedShowed);
    // CsFyberAd().setRewardedClicked(rewardedClicked);
    // CsFyberAd().setRewardedHided(rewardedHided);
    // CsFyberAd().setRewardedShowFailure(rewardedShowFailure);
    // CsFyberAd().setRewardedAvailable(rewardedAvailable);
    // CsFyberAd().setRewardedUnavailable(rewardedUnavailable);
    // CsFyberAd().setRewardedCompletion(rewardedCompletion);
    // CsFyberAd().setRewardedRequestStart(rewardedRequestStart);

    // CsFyberAd().setInterstitialShowed(interstitialShowed);
    // CsFyberAd().setInterstitialClicked(interstitialClicked);
    // CsFyberAd().setInterstitialHided(interstitialHided);
    // CsFyberAd().setInterstitialShowFailure(interstitialShowFailure);
    // CsFyberAd().setInterstitialAvailable(interstitialAvailable);
    // CsFyberAd().setInterstitialUnavailable(interstitialUnavailable);
    // CsFyberAd().setInterstitialRequestStart(interstitialRequestStart);

    // CsFyberAd().setBannerLoaded(bannerLoaded);
    // CsFyberAd().setBannerShowed(bannerShowed);
    // CsFyberAd().setBannerClicked(bannerClicked);
    // CsFyberAd().setBannerRequestStart(bannerRequestStart);
    // CsFyberAd().setBannerError(bannerError);
    CsFyberAd().setDebugLog(isDebug: true);

    CsFyberAd().init(appId: "123867");
    CsFyberAd().setUserId(userId: "userId");
    CsFyberAd().setupOfferWall(securityToken: "3099e5c8ccd1e184f115fed6de573f80");
    CsFyberAd().requestOfferWall(placementId: "Default");
  }

  offerWallAvailable() {
    log("CSFyber callback: offerWallAvailable");
  }

  offerWallNotAvailable(String formatMess) {
    log("CSFyber callback: offerWallNotAvailable = formatMess - " + formatMess);
  }

  offerWallRequestError(String errorMess) {
    log("CSFyber callback: offerWallRequestError = errorMess - " + errorMess);
  }

  // mediationNetworkStarted(String name, String version) {
  //   log("CSFyber callback: mediationNetworkStarted = name - " + name + ", version - " + version);
  // }

  // mediationNetworkFailed(String name, String version, String errorMessage) {
  //   log("CSFyber callback: mediationNetworkFailed = name - " + name + ", version - " + version + ", errorMessage - " + errorMessage);
  // }

  // rewardedShowed(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: rewardedShowed = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // rewardedClicked(String placementId) {
  //   log("CSFyber callback: rewardedClicked = placementId - " + placementId);
  // }

  // rewardedHided(String placementId) {
  //   log("CSFyber callback: rewardedHided = placementId - " + placementId);
  // }

  // rewardedShowFailure(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: rewardedShowFailure = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // rewardedAvailable(String placementId) {
  //   log("CSFyber callback: rewardedAvailable = placementId - " + placementId);
  // }

  // rewardedUnavailable(String placementId) {
  //   log("CSFyber callback: rewardedUnavailable = placementId - " + placementId);
  // }

  // rewardedCompletion(String placementId, bool success) {
  //   log("CSFyber callback: rewardedCompletion = placementId - " + placementId + ", success - " + success.toString());
  // }

  // rewardedRequestStart(String placementId) {
  //   log("CSFyber callback: rewardedRequestStart = placementId - " + placementId);
  // }

  // interstitialShowed(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: interstitialShowed = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // interstitialClicked(String placementId) {
  //   log("CSFyber callback: interstitialClicked = placementId - " + placementId);
  // }

  // interstitialHided(String placementId) {
  //   log("CSFyber callback: interstitialHided = placementId - " + placementId);
  // }

  // interstitialShowFailure(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: interstitialShowFailure = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // interstitialAvailable(String placementId) {
  //   log("CSFyber callback: interstitialAvailable = placementId - " + placementId);
  // }

  // interstitialUnavailable(String placementId) {
  //   log("CSFyber callback: interstitialUnavailable = placementId - " + placementId);
  // }

  // interstitialRequestStart(String placementId) {
  //   log("CSFyber callback: interstitialRequestStart = placementId - " + placementId);
  // }

  // bannerLoaded(String placementId) {
  //   log("CSFyber callback: bannerLoaded = placementId - " + placementId);
  // }

  // bannerShowed(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: bannerShowed = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // bannerClicked(String placementId) {
  //   log("CSFyber callback: bannerClicked = placementId - " + placementId);
  // }

  // bannerRequestStart(String placementId) {
  //   log("CSFyber callback: bannerRequestStart = placementId - " + placementId);
  // }

  // bannerError(String placementId, String message) {
  //   log("CSFyber callback: bannerError = placementId - " + placementId + ", message - " + message);
  // }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: TextButton(
            onPressed: () {
              CsFyberAd().showOfferWall();
            },
            child: const Text(
              "showReward",
              style: TextStyle(color: Colors.red),
            ),
          ),
        ),
      ),
    );
  }
}

==> cs_fyber_ad-0.0.6.tar.gz: example/lib/main.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'package:cs_fyber_ad/cs_fyber_ad.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatefulWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    super.initState();

    CsFyberAd().setOfferWallAvailable(offerWallAvailable);
    CsFyberAd().setOfferWallNotAvailable(offerWallNotAvailable);
    CsFyberAd().setOfferWallRequestError(offerWallRequestError);

    // CsFyberAd().setMediationNetworkStarted(mediationNetworkStarted);
    // CsFyberAd().setMediationNetworkFailed(mediationNetworkFailed);

    // CsFyberAd().setRewardedShowed(rewardedShowed);
    // CsFyberAd().setRewardedClicked(rewardedClicked);
    // CsFyberAd().setRewardedHided(rewardedHided);
    // CsFyberAd().setRewardedShowFailure(rewardedShowFailure);
    // CsFyberAd().setRewardedAvailable(rewardedAvailable);
    // CsFyberAd().setRewardedUnavailable(rewardedUnavailable);
    // CsFyberAd().setRewardedCompletion(rewardedCompletion);
    // CsFyberAd().setRewardedRequestStart(rewardedRequestStart);

    // CsFyberAd().setInterstitialShowed(interstitialShowed);
    // CsFyberAd().setInterstitialClicked(interstitialClicked);
    // CsFyberAd().setInterstitialHided(interstitialHided);
    // CsFyberAd().setInterstitialShowFailure(interstitialShowFailure);
    // CsFyberAd().setInterstitialAvailable(interstitialAvailable);
    // CsFyberAd().setInterstitialUnavailable(interstitialUnavailable);
    // CsFyberAd().setInterstitialRequestStart(interstitialRequestStart);

    // CsFyberAd().setBannerLoaded(bannerLoaded);
    // CsFyberAd().setBannerShowed(bannerShowed);
    // CsFyberAd().setBannerClicked(bannerClicked);
    // CsFyberAd().setBannerRequestStart(bannerRequestStart);
    // CsFyberAd().setBannerError(bannerError);
    CsFyberAd().setDebugLog(isDebug: true);

    CsFyberAd().init(appId: "123456");
    CsFyberAd().setUserId(userId: "userId");
    CsFyberAd().setupOfferWall(securityToken: "token");
    CsFyberAd().requestOfferWall(placementId: "Default");
  }

  offerWallAvailable() {
    log("CSFyber callback: offerWallAvailable");
  }

  offerWallNotAvailable(String formatMess) {
    log("CSFyber callback: offerWallNotAvailable = formatMess - " + formatMess);
  }

  offerWallRequestError(String errorMess) {
    log("CSFyber callback: offerWallRequestError = errorMess - " + errorMess);
  }

  // mediationNetworkStarted(String name, String version) {
  //   log("CSFyber callback: mediationNetworkStarted = name - " + name + ", version - " + version);
  // }

  // mediationNetworkFailed(String name, String version, String errorMessage) {
  //   log("CSFyber callback: mediationNetworkFailed = name - " + name + ", version - " + version + ", errorMessage - " + errorMessage);
  // }

  // rewardedShowed(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: rewardedShowed = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // rewardedClicked(String placementId) {
  //   log("CSFyber callback: rewardedClicked = placementId - " + placementId);
  // }

  // rewardedHided(String placementId) {
  //   log("CSFyber callback: rewardedHided = placementId - " + placementId);
  // }

  // rewardedShowFailure(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: rewardedShowFailure = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // rewardedAvailable(String placementId) {
  //   log("CSFyber callback: rewardedAvailable = placementId - " + placementId);
  // }

  // rewardedUnavailable(String placementId) {
  //   log("CSFyber callback: rewardedUnavailable = placementId - " + placementId);
  // }

  // rewardedCompletion(String placementId, bool success) {
  //   log("CSFyber callback: rewardedCompletion = placementId - " + placementId + ", success - " + success.toString());
  // }

  // rewardedRequestStart(String placementId) {
  //   log("CSFyber callback: rewardedRequestStart = placementId - " + placementId);
  // }

  // interstitialShowed(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: interstitialShowed = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // interstitialClicked(String placementId) {
  //   log("CSFyber callback: interstitialClicked = placementId - " + placementId);
  // }

  // interstitialHided(String placementId) {
  //   log("CSFyber callback: interstitialHided = placementId - " + placementId);
  // }

  // interstitialShowFailure(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: interstitialShowFailure = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // interstitialAvailable(String placementId) {
  //   log("CSFyber callback: interstitialAvailable = placementId - " + placementId);
  // }

  // interstitialUnavailable(String placementId) {
  //   log("CSFyber callback: interstitialUnavailable = placementId - " + placementId);
  // }

  // interstitialRequestStart(String placementId) {
  //   log("CSFyber callback: interstitialRequestStart = placementId - " + placementId);
  // }

  // bannerLoaded(String placementId) {
  //   log("CSFyber callback: bannerLoaded = placementId - " + placementId);
  // }

  // bannerShowed(String placementId, String impressionDataStr) {
  //   log("CSFyber callback: bannerShowed = placementId - " + placementId + ", impressionDataStr - " + impressionDataStr);
  // }

  // bannerClicked(String placementId) {
  //   log("CSFyber callback: bannerClicked = placementId - " + placementId);
  // }

  // bannerRequestStart(String placementId) {
  //   log("CSFyber callback: bannerRequestStart = placementId - " + placementId);
  // }

  // bannerError(String placementId, String message) {
  //   log("CSFyber callback: bannerError = placementId - " + placementId + ", message - " + message);
  // }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Plugin example app'),
        ),
        body: Center(
          child: TextButton(
            onPressed: () {
              CsFyberAd().showOfferWall();
            },
            child: const Text(
              "showReward",
              style: TextStyle(color: Colors.red),
            ),
          ),
        ),
      ),
    );
  }
}
